groff-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[groff] 31/35: font/devpdf/util/BuildFoundries.pl: Recast diag.


From: G. Branden Robinson
Subject: [groff] 31/35: font/devpdf/util/BuildFoundries.pl: Recast diag.
Date: Fri, 15 Jul 2022 23:12:00 -0400 (EDT)

gbranden pushed a commit to branch master
in repository groff.

commit 5ee1e5893477273584aba3c4e25cea77c0f2d5d8
Author: G. Branden Robinson <g.branden.robinson@gmail.com>
AuthorDate: Wed Jul 13 02:25:09 2022 -0500

    font/devpdf/util/BuildFoundries.pl: Recast diag.
    
    * font/devpdf/util/BuildFoundries.pl (LoadFoundry): Recast diagnostic
      message so that the user understands the consequence of failure to
      locate a Type 1 font file (that isn't one of the base 14 PostScript
      level 1 fonts): the font will be unavailable for the "pdf" output
      device.
---
 ChangeLog                          |  8 ++++++++
 font/devpdf/util/BuildFoundries.pl | 17 +++++++++++------
 2 files changed, 19 insertions(+), 6 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index defaa492..9dabfc1f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,11 @@
+2022-07-13  G. Branden Robinson <g.branden.robinson@gmail.com>
+
+       * font/devpdf/util/BuildFoundries.pl (LoadFoundry): Recast
+       diagnostic message so that the user understands the consequence
+       of failure to locate a Type 1 font file (that isn't one of the
+       base 14 PostScript level 1 fonts): the font will be unavailable
+       for the "pdf" output device.
+
 2022-07-13  G. Branden Robinson <g.branden.robinson@gmail.com>
 
        * font/devpdf/util/BuildFoundries.pl (LoadFoundry): Separate
diff --git a/font/devpdf/util/BuildFoundries.pl 
b/font/devpdf/util/BuildFoundries.pl
index f3b46047..b1af6b0f 100644
--- a/font/devpdf/util/BuildFoundries.pl
+++ b/font/devpdf/util/BuildFoundries.pl
@@ -116,23 +116,28 @@ sub LoadFoundry
 
            if ($r[2] eq '')
            {
-               # Don't run afmtodit, just copy the grops font file
-
+               # Don't run afmtodit; just copy the groff font
+               # description file for grops.
                my $gotf=1;
                my $gropsfnt=LocateFile($devps,$r[0],0);
-
                if ($gropsfnt ne '' and -r "$gropsfnt")
                {
                    my $psfont=UseGropsVersion($gropsfnt);
-                   if 
(!PutDownload($psfont,LocatePF($foundrypath,$r[5]),uc($r[1])))
+                   # To be embeddable in PDF, the font file name itself
+                   # needs to be located and written to "download".
+                   if (!PutDownload($psfont,
+                                    LocatePF($foundrypath,$r[5]),
+                                             uc($r[1])))
                    {
                        if (uc($r[1]) ne 'Y')
                        {
                            $gotf=0;
                            my $fns=join(', ',split('!',$r[5]));
-                           Warn("unable to locate font file(s): $fns");
+                           Warn("groff font '$gfont' will not be"
+                                . " available for PDF output; unable"
+                                . " to locate font file(s): $fns");
                            $notFoundFont=1;
-                           unlink $gfont;      # Unable to find the postscript 
file for the font just created by afmtodit
+                           unlink $gfont;
                        }
                    }
                    Notice("Copied grops font $gfont...") if $gotf;



reply via email to

[Prev in Thread] Current Thread [Next in Thread]